package com.abernard.xtext.air.serializer;

import com.abernard.xtext.air.air.AirPackage;
import com.abernard.xtext.air.air.Airline;
import com.abernard.xtext.air.air.Airport;
import com.abernard.xtext.air.air.CodeOACI;
import com.abernard.xtext.air.air.Includes;
import com.abernard.xtext.air.air.Model;
import com.abernard.xtext.air.air.Plane;
import com.abernard.xtext.air.services.AirGrammarAccess;
import com.google.inject.Inject;
import com.google.inject.Provider;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.xtext.serializer.acceptor.ISemanticSequenceAcceptor;
import org.eclipse.xtext.serializer.acceptor.SequenceFeeder;
import org.eclipse.xtext.serializer.diagnostic.ISemanticSequencerDiagnosticProvider;
import org.eclipse.xtext.serializer.diagnostic.ISerializationDiagnostic.Acceptor;
import org.eclipse.xtext.serializer.sequencer.AbstractDelegatingSemanticSequencer;
import org.eclipse.xtext.serializer.sequencer.GenericSequencer;
import org.eclipse.xtext.serializer.sequencer.ISemanticNodeProvider.INodesForEObjectProvider;
import org.eclipse.xtext.serializer.sequencer.ISemanticSequencer;
import org.eclipse.xtext.serializer.sequencer.ITransientValueService;
import org.eclipse.xtext.serializer.sequencer.ITransientValueService.ValueTransient;

@SuppressWarnings("all")
public class AirSemanticSequencer extends AbstractDelegatingSemanticSequencer {

	@Inject
	private AirGrammarAccess grammarAccess;
	
	public void createSequence(EObject context, EObject semanticObject) {
		if(semanticObject.eClass().getEPackage() == AirPackage.eINSTANCE) switch(semanticObject.eClass().getClassifierID()) {
			case AirPackage.AIRLINE:
				if(context == grammarAccess.getAirlineRule()) {
					sequence_Airline(context, (Airline) semanticObject); 
					return; 
				}
				else break;
			case AirPackage.AIRPORT:
				if(context == grammarAccess.getAirportRule()) {
					sequence_Airport(context, (Airport) semanticObject); 
					return; 
				}
				else break;
			case AirPackage.CODE_OACI:
				if(context == grammarAccess.getCodeOACIRule()) {
					sequence_CodeOACI(context, (CodeOACI) semanticObject); 
					return; 
				}
				else break;
			case AirPackage.INCLUDES:
				if(context == grammarAccess.getIncludesRule()) {
					sequence_Includes(context, (Includes) semanticObject); 
					return; 
				}
				else break;
			case AirPackage.MODEL:
				if(context == grammarAccess.getModelRule()) {
					sequence_Model(context, (Model) semanticObject); 
					return; 
				}
				else break;
			case AirPackage.PLANE:
				if(context == grammarAccess.getPlaneRule()) {
					sequence_Plane(context, (Plane) semanticObject); 
					return; 
				}
				else break;
			}
		if (errorAcceptor != null) errorAcceptor.accept(diagnosticProvider.createInvalidContextOrTypeDiagnostic(semanticObject, context));
	}
	
	/**
	 * Constraint:
	 *     (
	 *         name=STRING 
	 *         plane=[Plane|ID] 
	 *         company=STRING 
	 *         departure=[CodeOACI|OACI] 
	 *         arrival=[CodeOACI|OACI] 
	 *         duration=DURATION 
	 *         regular?='REGULIERE;'?
	 *     )
	 */
	protected void sequence_Airline(EObject context, Airline semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (title=STRING name=CodeOACI country=STRING runways=INT)
	 */
	protected void sequence_Airport(EObject context, Airport semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, AirPackage.Literals.AIRPORT__TITLE) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AirPackage.Literals.AIRPORT__TITLE));
			if(transientValues.isValueTransient(semanticObject, AirPackage.Literals.AIRPORT__NAME) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AirPackage.Literals.AIRPORT__NAME));
			if(transientValues.isValueTransient(semanticObject, AirPackage.Literals.AIRPORT__COUNTRY) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AirPackage.Literals.AIRPORT__COUNTRY));
			if(transientValues.isValueTransient(semanticObject, AirPackage.Literals.AIRPORT__RUNWAYS) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AirPackage.Literals.AIRPORT__RUNWAYS));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getAirportAccess().getTitleSTRINGTerminalRuleCall_1_0(), semanticObject.getTitle());
		feeder.accept(grammarAccess.getAirportAccess().getNameCodeOACIParserRuleCall_3_0_2_0(), semanticObject.getName());
		feeder.accept(grammarAccess.getAirportAccess().getCountrySTRINGTerminalRuleCall_3_1_2_0(), semanticObject.getCountry());
		feeder.accept(grammarAccess.getAirportAccess().getRunwaysINTTerminalRuleCall_3_2_2_0(), semanticObject.getRunways());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     name=OACI
	 */
	protected void sequence_CodeOACI(EObject context, CodeOACI semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, AirPackage.Literals.CODE_OACI__NAME) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AirPackage.Literals.CODE_OACI__NAME));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getCodeOACIAccess().getNameOACITerminalRuleCall_0(), semanticObject.getName());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     importURI=INCLUDE
	 */
	protected void sequence_Includes(EObject context, Includes semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, AirPackage.Literals.INCLUDES__IMPORT_URI) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AirPackage.Literals.INCLUDES__IMPORT_URI));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getIncludesAccess().getImportURIINCLUDETerminalRuleCall_2_0(), semanticObject.getImportURI());
		feeder.finish();
	}
	
	
	/**
	 * Constraint:
	 *     (includes+=Includes* (planes+=Plane | airports+=Airport)* airlines+=Airline*)
	 */
	protected void sequence_Model(EObject context, Model semanticObject) {
		genericSequencer.createSequence(context, semanticObject);
	}
	
	
	/**
	 * Constraint:
	 *     (name=ID passengers=INT motorisation=Engines)
	 */
	protected void sequence_Plane(EObject context, Plane semanticObject) {
		if(errorAcceptor != null) {
			if(transientValues.isValueTransient(semanticObject, AirPackage.Literals.PLANE__NAME) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AirPackage.Literals.PLANE__NAME));
			if(transientValues.isValueTransient(semanticObject, AirPackage.Literals.PLANE__PASSENGERS) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AirPackage.Literals.PLANE__PASSENGERS));
			if(transientValues.isValueTransient(semanticObject, AirPackage.Literals.PLANE__MOTORISATION) == ValueTransient.YES)
				errorAcceptor.accept(diagnosticProvider.createFeatureValueMissing(semanticObject, AirPackage.Literals.PLANE__MOTORISATION));
		}
		INodesForEObjectProvider nodes = createNodeProvider(semanticObject);
		SequenceFeeder feeder = createSequencerFeeder(semanticObject, nodes);
		feeder.accept(grammarAccess.getPlaneAccess().getNameIDTerminalRuleCall_1_0(), semanticObject.getName());
		feeder.accept(grammarAccess.getPlaneAccess().getPassengersINTTerminalRuleCall_3_0_2_0(), semanticObject.getPassengers());
		feeder.accept(grammarAccess.getPlaneAccess().getMotorisationEnginesEnumRuleCall_3_1_2_0(), semanticObject.getMotorisation());
		feeder.finish();
	}
}
